pub struct CommandContext { /* private fields */ }Expand description
Context passed to process managers describing the current execution environment. Clones are cheap and explicit so background handles can own their working roots without juggling lifetimes.
Implementations
Sourceimpl CommandContext
impl CommandContext
pub fn new( cwd: &PolicyPath, envs: &HashMap<String, String>, cargo_target_dir: &GuardedPath, workspace_root: &GuardedPath, build_context: &GuardedPath, ) -> Self
pub fn cwd(&self) -> &PolicyPath
pub fn envs(&self) -> &HashMap<String, String>
pub fn cargo_target_dir(&self) -> &GuardedPath
pub fn workspace_root(&self) -> &GuardedPath
pub fn build_context(&self) -> &GuardedPath